@@ -52,6 +52,13 @@ def status_mercurial(path, ignore_set):
     st = process.stdout.read()
     lines = [ l for l in st.splitlines() if not l.startswith('?') ]
     return lines
+    
+def status_git(path, ignore_set):
+    """Return text lines describing the status of a Git repository."""
+    process = Popen(('git', 'st', '-s'), stdout=PIPE, cwd=path)
+    st = process.stdout.read()
+    lines = [ l for l in st.splitlines() if not l.startswith('?') ]
+    return lines    
 
 def status_subversion(path, ignore_set):
     """Return text lines describing the status of a Subversion repository."""
@@ -72,9 +79,12 @@ def status_subversion(path, ignore_set):
             keepers.append(status + filename)
     return keepers
 
-DOTDIRS = {'.hg': 'Mercurial', '.svn': 'Subversion'}
-STATUS_FUNCTIONS = {'Mercurial': status_mercurial,
-                    'Subversion': status_subversion}
+DOTDIRS = {'.hg': 'Mercurial', '.git': 'Git', '.svn': 'Subversion'}
+STATUS_FUNCTIONS = {
+    'Mercurial': status_mercurial,
+    'Git': status_git,
+    'Subversion': status_subversion,
+    }
 
 def scan(repos, verbose):
     """Given a repository list [(path, vcsname), ...], scan each of them."""
